%global srcname dask

# Requires distributed, which is a loop.
%{?_with_bootstrap: %global bootstrap 1}
# Force bootstrap for package review.
%global bootstrap 1

Name:           python-%{srcname}
Version:        1.1.3
Release:        3%{?dist}
Summary:        Parallel PyData with Task Scheduling

License:        BSD
URL:            http://github.com/dask/dask/
Source0:        https://files.pythonhosted.org/packages/source/d/%{srcname}/%{srcname}-%{version}.tar.gz
# https://github.com/dask/dask/issues/2022
Patch0001:      0001-Mark-test_cov_corr_stable-xfail-on-32-bit.patch
# https://github.com/dask/dask/pull/4539
Patch0002:      0002-Use-correct-dtype-when-test-concatenation.patch
# https://github.com/dask/dask/issues/2022
Patch0003:      0003-XFail-partitioning-test-on-some-arches.patch

BuildArch:      noarch

%description
Dask is a flexible parallel computing library for analytics.


%package -n     python3-%{srcname}
Summary:        %{summary}
%{?python_provide:%python_provide python3-%{srcname}}

BuildRequires:  python3-devel
BuildRequires:  python3dist(cloudpickle) >= 0.2.1
BuildRequires:  python3dist(graphviz)
BuildRequires:  python3dist(ipython)
BuildRequires:  python3dist(numpy) >= 1.11.0
BuildRequires:  python3dist(pandas) >= 0.19.0
BuildRequires:  python3dist(partd) >= 0.3.8
BuildRequires:  python3dist(pytest)
BuildRequires:  python3dist(pyyaml)
BuildRequires:  python3dist(setuptools)
BuildRequires:  python3dist(toolz) >= 0.7.3
%if ! 0%{?bootstrap}
BuildRequires:  python3dist(distributed) >= 1.22
%endif

Recommends:     python3-%{srcname}+array = %{version}-%{release}
Recommends:     python3-%{srcname}+bag = %{version}-%{release}
Recommends:     python3-%{srcname}+dataframe = %{version}-%{release}
Recommends:     python3-%{srcname}+delayed = %{version}-%{release}
Recommends:     python3-%{srcname}+distributed = %{version}-%{release}

%description -n python3-%{srcname}
Dask is a flexible parallel computing library for analytics.


%package -n     python3-%{srcname}+array
Summary:        Meta-package for python3-%{srcname} with array feature
BuildArch:      noarch
%{?python_provide:%python_provide python3-%{srcname}+array}

Requires:       python3-%{srcname} = %{version}-%{release}
Requires:       python3dist(numpy) >= 1.11.0
Requires:       python3dist(toolz) >= 0.7.3

%description -n python3-%{srcname}+array
This package installs dask with dependencies required for its array feature.
Dask is a flexible parallel computing library for analytics.


%package -n     python3-%{srcname}+bag
Summary:        Meta-package for python3-%{srcname} with bag feature
BuildArch:      noarch
%{?python_provide:%python_provide python3-%{srcname}+bag}

Requires:       python3-%{srcname} = %{version}-%{release}
Requires:       python3dist(cloudpickle) >= 0.2.1
Requires:       python3dist(partd) >= 0.3.8
Requires:       python3dist(toolz) >= 0.7.3

%description -n python3-%{srcname}+bag
This package installs dask with dependencies required for its bag feature.
Dask is a flexible parallel computing library for analytics.


%package -n     python3-%{srcname}+dataframe
Summary:        Meta-package for python3-%{srcname} with dataframe feature
BuildArch:      noarch
%{?python_provide:%python_provide python3-%{srcname}+dataframe}

Requires:       python3-%{srcname} = %{version}-%{release}
Requires:       python3dist(cloudpickle) >= 0.2.1
Requires:       python3dist(numpy) >= 1.11.0
Requires:       python3dist(pandas) >= 0.19.0
Requires:       python3dist(partd) >= 0.3.8
Requires:       python3dist(toolz) >= 0.7.3

%description -n python3-%{srcname}+dataframe
This package installs dask with dependencies required for its dataframe
feature.
Dask is a flexible parallel computing library for analytics.


%package -n     python3-%{srcname}+delayed
Summary:        Meta-package for python3-%{srcname} with delayed feature
BuildArch:      noarch
%{?python_provide:%python_provide python3-%{srcname}+delayed}

Requires:       python3-%{srcname} = %{version}-%{release}
Requires:       python3dist(toolz) >= 0.7.3

%description -n python3-%{srcname}+delayed
This package installs dask with dependencies required for its delayed feature.
Dask is a flexible parallel computing library for analytics.


%package -n     python3-%{srcname}+distributed
Summary:        Meta-package for python3-%{srcname} with distributed feature
BuildArch:      noarch
%{?python_provide:%python_provide python3-%{srcname}+distributed}

Requires:       python3-%{srcname} = %{version}-%{release}
Requires:       python3dist(distributed) >= 1.22

%description -n python3-%{srcname}+distributed
This package installs dask with dependencies required for its distributed
feature.
Dask is a flexible parallel computing library for analytics.


%if ! 0%{?bootstrap}
%package -n python-%{srcname}-doc
Summary:        dask documentation

BuildRequires:  python3dist(dask_sphinx_theme)
BuildRequires:  python3dist(numpydoc)
BuildRequires:  python3dist(sphinx)

%description -n python-%{srcname}-doc
Documentation for dask
%endif


%prep
%autosetup -n %{srcname}-%{version} -p1

# Remove bundled egg-info
rm -rf %{srcname}.egg-info


%build
%py3_build

%if ! 0%{?bootstrap}
# generate html docs
PYTHONPATH=${PWD} sphinx-build-3 docs/source html
# remove the sphinx-build leftovers
rm -rf html/.{doctrees,buildinfo}
%endif


%install
%py3_install


%check
PYTHONDONTWRITEBYTECODE=1 \
    %{__python3} -m pytest -m 'not network'


%files -n python3-%{srcname}
%doc README.rst
%license LICENSE.txt
%{python3_sitelib}/%{srcname}
%{python3_sitelib}/%{srcname}-%{version}-py?.?.egg-info

%files -n python3-%{srcname}+array
%files -n python3-%{srcname}+bag
%files -n python3-%{srcname}+dataframe
%files -n python3-%{srcname}+delayed
%files -n python3-%{srcname}+distributed

%if ! 0%{?bootstrap}
%files -n python-%{srcname}-doc
%doc html
%license LICENSE.txt
%endif


%changelog
* Wed Mar 06 2019 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 1.1.3-3
- Mark partitioning test as expected failure on 32-bit systems as well

* Wed Mar 06 2019 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 1.1.3-2
- Add meta-subpackages for individual features

* Sat Mar 02 2019 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 1.1.3-1
- Initial package.
